summaryrefslogtreecommitdiffstats
path: root/chromium/third_party/webrtc/tools/frame_analyzer/video_quality_analysis.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/third_party/webrtc/tools/frame_analyzer/video_quality_analysis.h')
-rw-r--r--chromium/third_party/webrtc/tools/frame_analyzer/video_quality_analysis.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/chromium/third_party/webrtc/tools/frame_analyzer/video_quality_analysis.h b/chromium/third_party/webrtc/tools/frame_analyzer/video_quality_analysis.h
index b2ecc082c75..31064a28f81 100644
--- a/chromium/third_party/webrtc/tools/frame_analyzer/video_quality_analysis.h
+++ b/chromium/third_party/webrtc/tools/frame_analyzer/video_quality_analysis.h
@@ -97,13 +97,14 @@ bool IsThereBarcodeError(std::string line);
// frame_0023 0284, we will get 284.
int ExtractDecodedFrameNumber(std::string line);
-// Gets the next frame from an open I420 file.
-bool GetNextI420Frame(FILE* input_file, int width, int height,
- uint8* result_frame);
-
-// Extracts an I420 frame at position frame_number from the file.
-bool ExtractFrameFromI420(const char* i420_file_name, int width, int height,
- int frame_number, uint8* result_frame);
+// Extracts an I420 frame at position frame_number from the raw YUV file.
+bool ExtractFrameFromYuvFile(const char* i420_file_name, int width, int height,
+ int frame_number, uint8* result_frame);
+
+// Extracts an I420 frame at position frame_number from the Y4M file. The first
+// frame has corresponded |frame_number| 0.
+bool ExtractFrameFromY4mFile(const char* i420_file_name, int width, int height,
+ int frame_number, uint8* result_frame);
} // namespace test